==> lhcsmapi-1.1.185.tar.gz: lhcsmapi-1.1.185/lhcsmapi/analysis/pc/PowerConverterPlot.py <==
import matplotlib.pyplot as plt

from ...Time import Time


class PowerConverterPlot(object):

    @staticmethod
    def plot_fgc_current(i_meas_df, i_meas_ref_df, timestamp_fgc_act, timestamp_pic, circuit_name):
        title = '{} {}: I_MEAS(t) and I_MEAS(t)/dI_MEAS(t) (+PNO.b2)\n'.format(
            Time.convertToString(timestamp_fgc_act)[:23], circuit_name)

        ax1 = i_meas_df['I_MEAS'].plot(color='C0', legend=True, grid=True)
        i_meas_ref_df['I_MEAS'].plot(ax=ax1, color='C1', style='--', grid=True)
        ax1.set_ylabel("I_MEAS [A]", color='C0', fontsize=15)
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.legend(['I_MEAS', 'I_MEAS (PNO.b2)'], loc='lower left')
        ax1.tick_params(labelsize=16)

        ax2 = ax1.twinx()
        i_meas_df["I_MEAS/dI_MEAS"].plot(ax=ax2, title=title, figsize=(15, 10), ylim=(50, 110), color='C3',
                                         legend=True)
        i_meas_ref_df["I_MEAS/dI_MEAS"].plot(ax=ax2, color='C2', legend=True, style='--')
        ax2.title.set_size(20)
        ax2.set_ylabel("I_MEAS : dI_MEAS/dt [s]", color='C3', fontsize=15)
        ax2.legend(['I_MEAS/dI_MEAS', 'I_MEAS/dI_MEAS (PNO.b2)'], loc='upper right')

        plot_text = ("PIC Abort: " + Time.convertToString(timestamp_pic)[:23] + "\n\n"
                     + "PC Off:      " + Time.convertToString(timestamp_fgc_act)[:23] + "\n\n"
                     + "max(I_MEAS) =" + str(int(i_meas_df['I_MEAS'].max())) + " A")
        ax2.annotate(plot_text, xytext=(420, 50), xy=(20, 50), fontsize=15)
        ax2.tick_params(labelsize=16)
        plt.show()

    @staticmethod
    def plot_earth_current(i_a_df, i_earth_df, i_earth_ref_df, timestamp_fgc_act, circuit_name):
        title = '{} {}: I_A and I_EARTH (+PNO.b2)'.format(Time.convertToString(timestamp_fgc_act)[:23], circuit_name)
        ax1 = i_a_df['I_A'].plot(title=title, figsize=(15, 7.5), color='C0', grid=True, legend=True)
        ax1.title.set_size(20)
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.set_ylabel("I_A [A]", color='C0', fontsize=15)
        ax1.legend(loc='lower left')
        ax1.tick_params(labelsize=15)

        ax2 = ax1.twinx()
        i_earth_df['IEARTH'].plot(ax=ax2, xlim=(-1, 5), color='C2', legend=True)
        i_earth_ref_df['IEARTH'].plot(ax=ax2, xlim=(-1, 5), color='C3', style='--')
        ax2.set_ylabel("IEARTH [A]", color='C2', fontsize=15)
        ax2.legend(['IEARTH', 'IEARTH (PNO.b2)'], loc='upper right')
        ax2.tick_params(labelsize=15)
        plt.show()

    @staticmethod
    def plot_earth_current_pcnt(i_meas_df, i_earth_pcnt_df, i_earth_pcnt_ref_df, timestamp_fgc_act, circuit_name):
        title = '{} {}: I_MEAS and I_EARTH (+PNO.b2)'.format(Time.convertToString(timestamp_fgc_act)[:23], circuit_name)
        ax1 = i_meas_df["I_MEAS"].plot(title=title, figsize=(15, 7.5), color='C0', grid=True, legend=True)
        ax1.title.set_size(20)
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.legend(loc='lower left')
        ax1.set_ylabel("I_MEAS [A]", color='C0', fontsize=15)
        ax1.tick_params(labelsize=15)

        ax2 = ax1.twinx()
        i_earth_pcnt_df['I_EARTH_PCNT'].plot(ax=ax2, color='C2', legend=True)
        i_earth_pcnt_ref_df['I_EARTH_PCNT'].plot(ax=ax2, color='C3', yerr=3, fmt='none')
        ax2.legend(['I_EARTH_PCNT', 'I_EARTH_PCNT (PNO.b2)'], loc='upper right')
        ax2.set_ylabel("I_EARTH_PCNT [%]", color='C2', fontsize=15)
        ax2.tick_params(labelsize=15)
        plt.show()

==> lhcsmapi-1.2.19.tar.gz: lhcsmapi-1.2.19/lhcsmapi/analysis/pc/PowerConverterPlot.py <==
import matplotlib.pyplot as plt

from lhcsmapi.Time import Time


class PowerConverterPlot(object):

    @staticmethod
    def plot_fgc_current(i_meas_df, i_meas_ref_df, timestamp_fgc_act, timestamp_pic, circuit_name, tau_i_meas, tau_i_meas_ref):
        title = '{} {}: I_MEAS(t) and I_MEAS(t)/dI_MEAS(t) (+PNO.b2)\n'.format(
            Time.to_string_short(timestamp_fgc_act), circuit_name)

        ax1 = i_meas_df['I_MEAS'].plot(color='C0', legend=True, grid=True)
        i_meas_ref_df['I_MEAS'].plot(ax=ax1, color='C1', style='--', grid=True)
        ax1.set_ylabel("I_MEAS [A]", color='C0', fontsize=15)
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.legend(['I_MEAS', 'I_MEAS (PNO.b2)'], loc='lower left')
        ax1.tick_params(labelsize=16)

        ax2 = ax1.twinx()

        i_meas_df["I_MEAS/dI_MEAS"].plot(ax=ax2, title=title, figsize=(15, 10), color='C3', legend=True)
        i_meas_ref_df["I_MEAS/dI_MEAS"].plot(ax=ax2, color='C2', legend=True, style='--')
        ax2.title.set_size(20)
        ax2.set_ylabel("I_MEAS : dI_MEAS/dt [s]", color='C3', fontsize=15)
        ax2.legend(['-I_MEAS/dI_MEAS', '-I_MEAS/dI_MEAS (PNO.b2)'], loc='upper right')
        ax2.set_ylim(50, 110)

        plot_text = ("PIC Abort: {}\n\nPC Off:      {}\n\nmax(I_MEAS) = {} A\n\nI_MEAS: tau = {:.1f} s\n\nI_MEAS(PNO.b2): tau = {:.1f} s".
                     format(Time.to_string_short(timestamp_pic), Time.to_string_short(timestamp_fgc_act),
                            int(i_meas_df['I_MEAS'].max()), tau_i_meas, tau_i_meas_ref))
        ax2.annotate(plot_text, xytext=(420, 50), xy=(20, 50), fontsize=15)
        ax2.tick_params(labelsize=16)
        plt.show()

    @staticmethod
    def plot_earth_current(i_a_df, i_earth_df, i_earth_ref_df, timestamp_fgc_act, circuit_name):
        title = '{} {}: I_A and I_EARTH (+PNO.b2)'.format(Time.to_string_short(timestamp_fgc_act), circuit_name)
        ax1 = i_a_df['I_A'].plot(title=title, figsize=(15, 7.5), color='C0', grid=True, legend=True)
        ax1.title.set_size(20)
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.set_ylabel("I_A [A]", color='C0', fontsize=15)
        ax1.legend(loc='lower left')
        ax1.tick_params(labelsize=15)

        ax2 = ax1.twinx()
        i_earth_df['IEARTH'].plot(ax=ax2, xlim=(-1, 5), color='C2', legend=True)
        i_earth_ref_df['IEARTH'].plot(ax=ax2, xlim=(-1, 5), color='C3', style='--')
        ax2.set_ylabel("IEARTH [A]", color='C2', fontsize=15)
        ax2.legend(['IEARTH', 'IEARTH (PNO.b2)'], loc='upper right')
        ax2.tick_params(labelsize=15)
        plt.show()

    @staticmethod
    def plot_earth_current_pcnt(i_meas_df, i_earth_pcnt_df, i_earth_pcnt_ref_df, timestamp_fgc_act, circuit_name):
        title = '{} {}: I_MEAS and I_EARTH (+PNO.b2)'.format(Time.to_string_short(timestamp_fgc_act), circuit_name)
        ax1 = i_meas_df["I_MEAS"].plot(title=title, figsize=(15, 7.5), color='C0', grid=True, legend=True)
        ax1.title.set_size(20)
        ax1.set_xlabel("time, [s]", fontsize=15)
        ax1.legend(loc='lower left')
        ax1.set_ylabel("I_MEAS [A]", color='C0', fontsize=15)
        ax1.tick_params(labelsize=15)

        ax2 = ax1.twinx()
        i_earth_pcnt_df['I_EARTH_PCNT'].plot(ax=ax2, color='C2', legend=True)
        i_earth_pcnt_ref_df['I_EARTH_PCNT'].plot(ax=ax2, color='C3', yerr=3, fmt='none')
        ax2.legend(['I_EARTH_PCNT', 'I_EARTH_PCNT (PNO.b2)'], loc='upper right')
        ax2.set_ylabel("I_EARTH_PCNT [%]", color='C2', fontsize=15)
        ax2.tick_params(labelsize=15)
        plt.show()
